@@ -51,8 +51,11 @@ def find_category(annotations, category_id):
     return None
 
 
-def format_coco_file(annotations):
-    formatted_file = {"images": []}
+def format_coco_file(imgdir, annotations, train_assets, test_assets):
+    train_assets_fname = [e.filename for e in train_assets]
+    test_assets_fname = [e.filename for e in test_assets]
+    formatted_file_train = {"images": []}
+    formatted_file_test  = {"images": []}
     formatted_annotations = {}
     for shape in annotations["annotations"]:
         if shape["image_id"] in formatted_annotations.keys():
@@ -62,13 +65,14 @@ def format_coco_file(annotations):
             shape["label"] = find_category(annotations, shape["category_id"])
             formatted_annotations[shape["image_id"]] = [shape]
     for image in annotations["images"]:
+        image["path"] = os.path.join(imgdir, image["file_name"])
         tmp = image.copy()
-        try:
-            tmp["annotations"] = formatted_annotations[image["id"]]
-            formatted_file["images"].append(tmp)
-        except KeyError:
-            pass
-    return formatted_file
+        tmp["annotations"] = formatted_annotations[image["id"]]
+        if image["file_name"] in train_assets_fname:
+            formatted_file_train["images"].append(tmp)
+        if image["file_name"] in test_assets_fname:
+            formatted_file_test["images"].append(tmp)
+    return formatted_file_train, formatted_file_test
 
 
 def format_segmentation(shape):
@@ -83,13 +87,12 @@ def format_segmentation(shape):
 def create_record_files(
     annotation_path,
     train_list,
-    train_list_id,
     eval_list,
-    eval_list_id,
     label_path,
     record_dir,
     tfExample_generator,
     annotation_type,
+    imgdir,
 ):
     """
     Function used to create the TFRecord files used for the training and evaluation.
@@ -105,23 +108,24 @@ def create_record_files(
     """
     with open(annotation_path, "r") as f:
         annotations = json.load(f)
-    annotations = format_coco_file(annotations)
+    train_annotations, eval_annotations = format_coco_file(
+        imgdir=imgdir,
+        annotations=annotations,
+        train_assets=train_list,
+        test_assets=eval_list
+    )
     label_map = label_map_util.load_labelmap(label_path)
     label_map = label_map_util.get_label_map_dict(label_map)
     datasets = ["train", "eval"]
 
-    for dataset in datasets:
+    annotations_ensemble = [train_annotations, eval_annotations]
+    for i, dataset in enumerate(datasets):
         output_path = os.path.join(record_dir, dataset + ".record")
         writer = tf.compat.v1.python_io.TFRecordWriter(output_path)
         logger.info(f"Creating record file at {output_path}")
         for variables in tfExample_generator(
-            annotations,
-            train_list,
-            train_list_id,
-            eval_list,
-            eval_list_id,
+            annotations_ensemble[i],
             label_map,
-            ensemble=dataset,
             annotation_type=annotation_type,
         ):
             if isinstance(variables, ValueError):
